@@ -25,9 +25,6 @@
 #include <sonnet/backgroundchecker.h>
 #include <sonnet/spellcheckdecorator.h>
 #include <sonnet/speller.h>
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
-#include <KPIMTextEditTextToSpeech/TextToSpeech>
-#endif
 #ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
 #include <TextEditTextToSpeech/TextToSpeech>
 #endif
@@ -272,13 +269,6 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
             allowTabAction->setChecked(!tabChangesFocus());
             connect(allowTabAction, &QAction::triggered, this, &RichTextEditor::slotAllowTab);
         }
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
-        if (!emptyDocument) {
-            QAction *speakAction = popup->addAction(i18n("Speak Text"));
-            speakAction->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")));
-            connect(speakAction, &QAction::triggered, this, &RichTextEditor::slotSpeakText);
-        }
-#endif
 #ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
         if (!emptyDocument) {
             QAction *speakAction = popup->addAction(i18n("Speak Text"));
